nsi.granulate.tests.testGranulatePDF

Package nsi :: Package granulate :: Package tests :: Module testGranulatePDF |
[hide private]
[frames] | no frames]

# Module testGranulatePDF

source code

Author: Ronaldo Amaral Santos <ronaldinho.as@gmail.com>

Classes | [hide private]
| TestGranulatePDF

Variables | [hide private]
| filePath = ``'``/usr/lib/python2.4/site-packages/granulate-0.1dev-``...``
| filedata = ``'``%PDF-1.3\n%\xc7\xec\x8f\xa2\n5 0 obj\n<</Length 6` `...``

Variables Details | [hide private]

  ### filePath Value:
      '/usr/lib/python2.4/site-packages/granulate-0.1dev-py2.4.egg/nsi/granu
      late/tests/data/test.pdf'

  ### filedata Value:
      '''%PDF-1.3
      %\xc7\xec\x8f\xa2
      5 0 obj
      <</Length 6 0 R/Filter /FlateDecode>>
      stream
      x\x9c\xe5]\xd9\x92\x1b\xb7\x15\xadx7\xed\xf2\xf2\x07|\xc8\x03Y\x95\xe9
      `_\x1e\xad\xc5\x91lY\xcbx\xe4\xa4\x1c\xe5I^\xca\xa9\x92\x15\xc9\xf9\xe
      3<\xf87\x82\x0b4\xba\xd1\x1c\x1e`f\xba)2\x15\xbb\xca\x82\xfa\\\xe0\xde
      ...